@@ -14,13 +14,14 @@ cmake \
     -DCMAKE_BUILD_TYPE=release \
     -DCMAKE_INSTALL_PREFIX=$PREFIX \
     -DCMAKE_INSTALL_LIBDIR=$PREFIX/lib \
-    -DARROW_BOOST_USE_SHARED=OFF \
+    -DARROW_BOOST_USE_SHARED=ON \
     -DARROW_BUILD_BENCHMARKS=OFF \
     -DARROW_BUILD_UTILITIES=OFF \
     -DARROW_BUILD_TESTS=OFF \
     -DARROW_JEMALLOC=OFF \
     -DARROW_PLASMA=ON \
     -DARROW_PYTHON=ON \
+    -DARROW_ORC=ON \
     ..
 
 make -j${CPU_COUNT}
